Struct pallet_bags_list::List [−][src]
pub struct List<T: Config>(_);Expand description
The ONLY entry point of this module. All operations to the bags-list should happen through this interface. It is forbidden to access other module members directly.
Implementations
pub fn regenerate(
all: impl IntoIterator<Item = T::AccountId>,
weight_of: Box<dyn Fn(&T::AccountId) -> VoteWeight>
) -> u32
pub fn regenerate(
all: impl IntoIterator<Item = T::AccountId>,
weight_of: Box<dyn Fn(&T::AccountId) -> VoteWeight>
) -> u32
Regenerate all of the data from the given ids.
WARNING: this is expensive and should only ever be performed when the list needs to be generated from scratch. Care needs to be taken to ensure
This may or may not need to be called at genesis as well, based on the configuration of the
pallet using this List.
Returns the number of ids migrated.
Migrate the list from one set of thresholds to another.
This should only be called as part of an intentional migration; it’s fairly expensive.
Returns the number of accounts affected.
Preconditions:
old_thresholdsis the previous list of thresholds.- All
bag_uppercurrently in storage are members ofold_thresholds. T::BagThresholdshas already been updated and is the new set of thresholds.
Postconditions:
- All
bag_uppercurrently in storage are members ofT::BagThresholds. - No id is changed unless required to by the difference between the old threshold list and the new.
- ids whose bags change at all are implicitly rebagged into the appropriate bag in the new threshold set.